import converter.converts as cd

n = 20
print(cd.c2f(n))
print(cd.f2c(n))
print(cd.add_temp(n))